# coding: utf-8

from __future__ import absolute_import

import six

from postfinancecheckout.api_client import ApiClient

class TransactionVoidServiceApi:

    def __init__(self, configuration):
        self.api_client = ApiClient(configuration=configuration)

    def count(self, space_id, **kwargs):
        """Count

        Counts the number of items in the database as restricted by the given filter.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.count(space_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param EntityQueryFilter filter: The filter which restricts the entities which are used to calculate the count.
        :return: int
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.count_with_http_info(space_id, **kwargs)
        else:
            (data) = self.count_with_http_info(space_id, **kwargs)
            return data

    def count_with_http_info(self, space_id, **kwargs):
        """Count

        Counts the number of items in the database as restricted by the given filter.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.count_with_http_info(space_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param EntityQueryFilter filter: The filter which restricts the entities which are used to calculate the count.
        :return: int
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'filter']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method count" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `count`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'filter' in params:
            body_params = params['filter']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/transaction-void/count', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='int',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def read(self, space_id, id, **kwargs):
        """Read

        Reads the entity with the given 'id' and returns it.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.read(space_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int id: The id of the transaction voids which should be returned. (required)
        :return: TransactionVoid
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.read_with_http_info(space_id, id, **kwargs)
        else:
            (data) = self.read_with_http_info(space_id, id, **kwargs)
            return data

    def read_with_http_info(self, space_id, id, **kwargs):
        """Read

        Reads the entity with the given 'id' and returns it.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.read_with_http_info(space_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int id: The id of the transaction voids which should be returned. (required)
        :return: TransactionVoid
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'id']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method read" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `read`")
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `read`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))
        if 'id' in params:
            query_params.append(('id', params['id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['*/*'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/transaction-void/read', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TransactionVoid',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def search(self, space_id, query, **kwargs):
        """Search

        Searches for the entities as specified by the given query.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search(space_id, query, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param EntityQuery query: The query restricts the transaction voids which are returned by the search. (required)
        :return: list[TransactionVoid]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.search_with_http_info(space_id, query, **kwargs)
        else:
            (data) = self.search_with_http_info(space_id, query, **kwargs)
            return data

    def search_with_http_info(self, space_id, query, **kwargs):
        """Search

        Searches for the entities as specified by the given query.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search_with_http_info(space_id, query, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param EntityQuery query: The query restricts the transaction voids which are returned by the search. (required)
        :return: list[TransactionVoid]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'query']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method search" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `search`")
        # verify the required parameter 'query' is set
        if ('query' not in params or
                params['query'] is None):
            raise ValueError("Missing the required parameter `query` when calling `search`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'query' in params:
            body_params = params['query']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/transaction-void/search', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[TransactionVoid]',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def void_offline(self, space_id, id, **kwargs):
        """voidOffline

        This operation voids the transaction offline. The void is not forwarded to the processor. This implies the processor does not do anything. This method is only here to fix manually the transaction state.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.void_offline(space_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int id: The id of the transaction which should be voided. (required)
        :return: TransactionVoid
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.void_offline_with_http_info(space_id, id, **kwargs)
        else:
            (data) = self.void_offline_with_http_info(space_id, id, **kwargs)
            return data

    def void_offline_with_http_info(self, space_id, id, **kwargs):
        """voidOffline

        This operation voids the transaction offline. The void is not forwarded to the processor. This implies the processor does not do anything. This method is only here to fix manually the transaction state.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.void_offline_with_http_info(space_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int id: The id of the transaction which should be voided. (required)
        :return: TransactionVoid
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'id']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method void_offline" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `void_offline`")
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `void_offline`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))
        if 'id' in params:
            query_params.append(('id', params['id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/transaction-void/voidOffline', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TransactionVoid',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def void_online(self, space_id, id, **kwargs):
        """voidOnline

        This operation voids the transaction online. The void is forwarded to the processor. This implies that the processor may take some actions based on the void.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.void_online(space_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int id: The id of the transaction which should be voided. (required)
        :return: TransactionVoid
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.void_online_with_http_info(space_id, id, **kwargs)
        else:
            (data) = self.void_online_with_http_info(space_id, id, **kwargs)
            return data

    def void_online_with_http_info(self, space_id, id, **kwargs):
        """voidOnline

        This operation voids the transaction online. The void is forwarded to the processor. This implies that the processor may take some actions based on the void.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.void_online_with_http_info(space_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int id: The id of the transaction which should be voided. (required)
        :return: TransactionVoid
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'id']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method void_online" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `void_online`")
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `void_online`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))
        if 'id' in params:
            query_params.append(('id', params['id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/transaction-void/voidOnline', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TransactionVoid',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8
import pprint
import six
from enum import Enum



class TokenVersion:

    swagger_types = {
    
        'activated_on': 'datetime',
        'billing_address': 'Address',
        'created_on': 'datetime',
        'environment': 'ChargeAttemptEnvironment',
        'expires_on': 'datetime',
        'icon_url': 'str',
        'id': 'int',
        'labels': 'list[Label]',
        'language': 'str',
        'linked_space_id': 'int',
        'name': 'str',
        'obsoleted_on': 'datetime',
        'payment_connector_configuration': 'PaymentConnectorConfiguration',
        'payment_information_hashes': 'list[PaymentInformationHash]',
        'payment_method': 'int',
        'payment_method_brand': 'int',
        'planned_purge_date': 'datetime',
        'processor_token': 'str',
        'shipping_address': 'Address',
        'state': 'TokenVersionState',
        'token': 'Token',
        'type': 'TokenVersionType',
        'version': 'int',
    }

    attribute_map = {
        'activated_on': 'activatedOn','billing_address': 'billingAddress','created_on': 'createdOn','environment': 'environment','expires_on': 'expiresOn','icon_url': 'iconUrl','id': 'id','labels': 'labels','language': 'language','linked_space_id': 'linkedSpaceId','name': 'name','obsoleted_on': 'obsoletedOn','payment_connector_configuration': 'paymentConnectorConfiguration','payment_information_hashes': 'paymentInformationHashes','payment_method': 'paymentMethod','payment_method_brand': 'paymentMethodBrand','planned_purge_date': 'plannedPurgeDate','processor_token': 'processorToken','shipping_address': 'shippingAddress','state': 'state','token': 'token','type': 'type','version': 'version',
    }

    
    _activated_on = None
    _billing_address = None
    _created_on = None
    _environment = None
    _expires_on = None
    _icon_url = None
    _id = None
    _labels = None
    _language = None
    _linked_space_id = None
    _name = None
    _obsoleted_on = None
    _payment_connector_configuration = None
    _payment_information_hashes = None
    _payment_method = None
    _payment_method_brand = None
    _planned_purge_date = None
    _processor_token = None
    _shipping_address = None
    _state = None
    _token = None
    _type = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.activated_on = kwargs.get('activated_on', None)
        self.billing_address = kwargs.get('billing_address', None)
        self.created_on = kwargs.get('created_on', None)
        self.environment = kwargs.get('environment', None)
        self.expires_on = kwargs.get('expires_on', None)
        self.icon_url = kwargs.get('icon_url', None)
        self.id = kwargs.get('id', None)
        self.labels = kwargs.get('labels', None)
        self.language = kwargs.get('language', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.name = kwargs.get('name', None)
        self.obsoleted_on = kwargs.get('obsoleted_on', None)
        self.payment_connector_configuration = kwargs.get('payment_connector_configuration', None)
        self.payment_information_hashes = kwargs.get('payment_information_hashes', None)
        self.payment_method = kwargs.get('payment_method', None)
        self.payment_method_brand = kwargs.get('payment_method_brand', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.processor_token = kwargs.get('processor_token', None)
        self.shipping_address = kwargs.get('shipping_address', None)
        self.state = kwargs.get('state', None)
        self.token = kwargs.get('token', None)
        self.type = kwargs.get('type', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def activated_on(self):
        """Gets the activated_on of this TokenVersion.

            

        :return: The activated_on of this TokenVersion.
        :rtype: datetime
        """
        return self._activated_on

    @activated_on.setter
    def activated_on(self, activated_on):
        """Sets the activated_on of this TokenVersion.

            

        :param activated_on: The activated_on of this TokenVersion.
        :type: datetime
        """

        self._activated_on = activated_on
    
    @property
    def billing_address(self):
        """Gets the billing_address of this TokenVersion.

            

        :return: The billing_address of this TokenVersion.
        :rtype: Address
        """
        return self._billing_address

    @billing_address.setter
    def billing_address(self, billing_address):
        """Sets the billing_address of this TokenVersion.

            

        :param billing_address: The billing_address of this TokenVersion.
        :type: Address
        """

        self._billing_address = billing_address
    
    @property
    def created_on(self):
        """Gets the created_on of this TokenVersion.

            The created on date indicates the date on which the entity was stored into the database.

        :return: The created_on of this TokenVersion.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this TokenVersion.

            The created on date indicates the date on which the entity was stored into the database.

        :param created_on: The created_on of this TokenVersion.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def environment(self):
        """Gets the environment of this TokenVersion.

            

        :return: The environment of this TokenVersion.
        :rtype: ChargeAttemptEnvironment
        """
        return self._environment

    @environment.setter
    def environment(self, environment):
        """Sets the environment of this TokenVersion.

            

        :param environment: The environment of this TokenVersion.
        :type: ChargeAttemptEnvironment
        """

        self._environment = environment
    
    @property
    def expires_on(self):
        """Gets the expires_on of this TokenVersion.

            The expires on date indicates when token version expires. Once this date is reached the token version is marked as obsolete.

        :return: The expires_on of this TokenVersion.
        :rtype: datetime
        """
        return self._expires_on

    @expires_on.setter
    def expires_on(self, expires_on):
        """Sets the expires_on of this TokenVersion.

            The expires on date indicates when token version expires. Once this date is reached the token version is marked as obsolete.

        :param expires_on: The expires_on of this TokenVersion.
        :type: datetime
        """

        self._expires_on = expires_on
    
    @property
    def icon_url(self):
        """Gets the icon_url of this TokenVersion.

            

        :return: The icon_url of this TokenVersion.
        :rtype: str
        """
        return self._icon_url

    @icon_url.setter
    def icon_url(self, icon_url):
        """Sets the icon_url of this TokenVersion.

            

        :param icon_url: The icon_url of this TokenVersion.
        :type: str
        """

        self._icon_url = icon_url
    
    @property
    def id(self):
        """Gets the id of this TokenVersion.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :return: The id of this TokenVersion.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this TokenVersion.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :param id: The id of this TokenVersion.
        :type: int
        """

        self._id = id
    
    @property
    def labels(self):
        """Gets the labels of this TokenVersion.

            

        :return: The labels of this TokenVersion.
        :rtype: list[Label]
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this TokenVersion.

            

        :param labels: The labels of this TokenVersion.
        :type: list[Label]
        """

        self._labels = labels
    
    @property
    def language(self):
        """Gets the language of this TokenVersion.

            

        :return: The language of this TokenVersion.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this TokenVersion.

            

        :param language: The language of this TokenVersion.
        :type: str
        """

        self._language = language
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this TokenVersion.

            The linked space id holds the ID of the space to which the entity belongs to.

        :return: The linked_space_id of this TokenVersion.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this TokenVersion.

            The linked space id holds the ID of the space to which the entity belongs to.

        :param linked_space_id: The linked_space_id of this TokenVersion.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def name(self):
        """Gets the name of this TokenVersion.

            

        :return: The name of this TokenVersion.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TokenVersion.

            

        :param name: The name of this TokenVersion.
        :type: str
        """
        if name is not None and len(name) > 150:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `150`")

        self._name = name
    
    @property
    def obsoleted_on(self):
        """Gets the obsoleted_on of this TokenVersion.

            

        :return: The obsoleted_on of this TokenVersion.
        :rtype: datetime
        """
        return self._obsoleted_on

    @obsoleted_on.setter
    def obsoleted_on(self, obsoleted_on):
        """Sets the obsoleted_on of this TokenVersion.

            

        :param obsoleted_on: The obsoleted_on of this TokenVersion.
        :type: datetime
        """

        self._obsoleted_on = obsoleted_on
    
    @property
    def payment_connector_configuration(self):
        """Gets the payment_connector_configuration of this TokenVersion.

            

        :return: The payment_connector_configuration of this TokenVersion.
        :rtype: PaymentConnectorConfiguration
        """
        return self._payment_connector_configuration

    @payment_connector_configuration.setter
    def payment_connector_configuration(self, payment_connector_configuration):
        """Sets the payment_connector_configuration of this TokenVersion.

            

        :param payment_connector_configuration: The payment_connector_configuration of this TokenVersion.
        :type: PaymentConnectorConfiguration
        """

        self._payment_connector_configuration = payment_connector_configuration
    
    @property
    def payment_information_hashes(self):
        """Gets the payment_information_hashes of this TokenVersion.

            The payment information hash set contains hashes of the payment information represented by this token version.

        :return: The payment_information_hashes of this TokenVersion.
        :rtype: list[PaymentInformationHash]
        """
        return self._payment_information_hashes

    @payment_information_hashes.setter
    def payment_information_hashes(self, payment_information_hashes):
        """Sets the payment_information_hashes of this TokenVersion.

            The payment information hash set contains hashes of the payment information represented by this token version.

        :param payment_information_hashes: The payment_information_hashes of this TokenVersion.
        :type: list[PaymentInformationHash]
        """

        self._payment_information_hashes = payment_information_hashes
    
    @property
    def payment_method(self):
        """Gets the payment_method of this TokenVersion.

            

        :return: The payment_method of this TokenVersion.
        :rtype: int
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """Sets the payment_method of this TokenVersion.

            

        :param payment_method: The payment_method of this TokenVersion.
        :type: int
        """

        self._payment_method = payment_method
    
    @property
    def payment_method_brand(self):
        """Gets the payment_method_brand of this TokenVersion.

            

        :return: The payment_method_brand of this TokenVersion.
        :rtype: int
        """
        return self._payment_method_brand

    @payment_method_brand.setter
    def payment_method_brand(self, payment_method_brand):
        """Sets the payment_method_brand of this TokenVersion.

            

        :param payment_method_brand: The payment_method_brand of this TokenVersion.
        :type: int
        """

        self._payment_method_brand = payment_method_brand
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this TokenVersion.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :return: The planned_purge_date of this TokenVersion.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this TokenVersion.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :param planned_purge_date: The planned_purge_date of this TokenVersion.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def processor_token(self):
        """Gets the processor_token of this TokenVersion.

            

        :return: The processor_token of this TokenVersion.
        :rtype: str
        """
        return self._processor_token

    @processor_token.setter
    def processor_token(self, processor_token):
        """Sets the processor_token of this TokenVersion.

            

        :param processor_token: The processor_token of this TokenVersion.
        :type: str
        """
        if processor_token is not None and len(processor_token) > 150:
            raise ValueError("Invalid value for `processor_token`, length must be less than or equal to `150`")

        self._processor_token = processor_token
    
    @property
    def shipping_address(self):
        """Gets the shipping_address of this TokenVersion.

            

        :return: The shipping_address of this TokenVersion.
        :rtype: Address
        """
        return self._shipping_address

    @shipping_address.setter
    def shipping_address(self, shipping_address):
        """Sets the shipping_address of this TokenVersion.

            

        :param shipping_address: The shipping_address of this TokenVersion.
        :type: Address
        """

        self._shipping_address = shipping_address
    
    @property
    def state(self):
        """Gets the state of this TokenVersion.

            

        :return: The state of this TokenVersion.
        :rtype: TokenVersionState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this TokenVersion.

            

        :param state: The state of this TokenVersion.
        :type: TokenVersionState
        """

        self._state = state
    
    @property
    def token(self):
        """Gets the token of this TokenVersion.

            

        :return: The token of this TokenVersion.
        :rtype: Token
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this TokenVersion.

            

        :param token: The token of this TokenVersion.
        :type: Token
        """

        self._token = token
    
    @property
    def type(self):
        """Gets the type of this TokenVersion.

            The token version type determines what kind of token it is and by which payment connector the token can be processed by.

        :return: The type of this TokenVersion.
        :rtype: TokenVersionType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this TokenVersion.

            The token version type determines what kind of token it is and by which payment connector the token can be processed by.

        :param type: The type of this TokenVersion.
        :type: TokenVersionType
        """

        self._type = type
    
    @property
    def version(self):
        """Gets the version of this TokenVersion.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :return: The version of this TokenVersion.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this TokenVersion.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :param version: The version of this TokenVersion.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(TokenVersion, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, TokenVersion):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class TransactionInvoiceReplacement:

    swagger_types = {
    
        'billing_address': 'AddressCreate',
        'due_on': 'datetime',
        'external_id': 'str',
        'line_items': 'list[LineItemCreate]',
        'merchant_reference': 'str',
        'sent_to_customer': 'bool',
    }

    attribute_map = {
        'billing_address': 'billingAddress','due_on': 'dueOn','external_id': 'externalId','line_items': 'lineItems','merchant_reference': 'merchantReference','sent_to_customer': 'sentToCustomer',
    }

    
    _billing_address = None
    _due_on = None
    _external_id = None
    _line_items = None
    _merchant_reference = None
    _sent_to_customer = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.billing_address = kwargs.get('billing_address', None)
        self.due_on = kwargs.get('due_on', None)
        self.external_id = kwargs.get('external_id')

        self.line_items = kwargs.get('line_items')

        self.merchant_reference = kwargs.get('merchant_reference', None)
        self.sent_to_customer = kwargs.get('sent_to_customer', None)
        

    
    @property
    def billing_address(self):
        """Gets the billing_address of this TransactionInvoiceReplacement.

            

        :return: The billing_address of this TransactionInvoiceReplacement.
        :rtype: AddressCreate
        """
        return self._billing_address

    @billing_address.setter
    def billing_address(self, billing_address):
        """Sets the billing_address of this TransactionInvoiceReplacement.

            

        :param billing_address: The billing_address of this TransactionInvoiceReplacement.
        :type: AddressCreate
        """

        self._billing_address = billing_address
    
    @property
    def due_on(self):
        """Gets the due_on of this TransactionInvoiceReplacement.

            The date on which the invoice should be paid on.

        :return: The due_on of this TransactionInvoiceReplacement.
        :rtype: datetime
        """
        return self._due_on

    @due_on.setter
    def due_on(self, due_on):
        """Sets the due_on of this TransactionInvoiceReplacement.

            The date on which the invoice should be paid on.

        :param due_on: The due_on of this TransactionInvoiceReplacement.
        :type: datetime
        """

        self._due_on = due_on
    
    @property
    def external_id(self):
        """Gets the external_id of this TransactionInvoiceReplacement.

            The external id helps to identify the entity and a subsequent creation of an entity with the same ID will not create a new entity.

        :return: The external_id of this TransactionInvoiceReplacement.
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this TransactionInvoiceReplacement.

            The external id helps to identify the entity and a subsequent creation of an entity with the same ID will not create a new entity.

        :param external_id: The external_id of this TransactionInvoiceReplacement.
        :type: str
        """
        if external_id is None:
            raise ValueError("Invalid value for `external_id`, must not be `None`")
        if external_id is not None and len(external_id) > 100:
            raise ValueError("Invalid value for `external_id`, length must be less than or equal to `100`")
        if external_id is not None and len(external_id) < 1:
            raise ValueError("Invalid value for `external_id`, length must be greater than or equal to `1`")

        self._external_id = external_id
    
    @property
    def line_items(self):
        """Gets the line_items of this TransactionInvoiceReplacement.

            

        :return: The line_items of this TransactionInvoiceReplacement.
        :rtype: list[LineItemCreate]
        """
        return self._line_items

    @line_items.setter
    def line_items(self, line_items):
        """Sets the line_items of this TransactionInvoiceReplacement.

            

        :param line_items: The line_items of this TransactionInvoiceReplacement.
        :type: list[LineItemCreate]
        """
        if line_items is None:
            raise ValueError("Invalid value for `line_items`, must not be `None`")

        self._line_items = line_items
    
    @property
    def merchant_reference(self):
        """Gets the merchant_reference of this TransactionInvoiceReplacement.

            

        :return: The merchant_reference of this TransactionInvoiceReplacement.
        :rtype: str
        """
        return self._merchant_reference

    @merchant_reference.setter
    def merchant_reference(self, merchant_reference):
        """Sets the merchant_reference of this TransactionInvoiceReplacement.

            

        :param merchant_reference: The merchant_reference of this TransactionInvoiceReplacement.
        :type: str
        """
        if merchant_reference is not None and len(merchant_reference) > 100:
            raise ValueError("Invalid value for `merchant_reference`, length must be less than or equal to `100`")

        self._merchant_reference = merchant_reference
    
    @property
    def sent_to_customer(self):
        """Gets the sent_to_customer of this TransactionInvoiceReplacement.

            When the connector is configured to send the invoice to the customer and this property is true the customer will receive an email with the updated invoice. When this property is false no invoice is sent.

        :return: The sent_to_customer of this TransactionInvoiceReplacement.
        :rtype: bool
        """
        return self._sent_to_customer

    @sent_to_customer.setter
    def sent_to_customer(self, sent_to_customer):
        """Sets the sent_to_customer of this TransactionInvoiceReplacement.

            When the connector is configured to send the invoice to the customer and this property is true the customer will receive an email with the updated invoice. When this property is false no invoice is sent.

        :param sent_to_customer: The sent_to_customer of this TransactionInvoiceReplacement.
        :type: bool
        """

        self._sent_to_customer = sent_to_customer
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(TransactionInvoiceReplacement, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, TransactionInvoiceReplacement):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
